PrinterStatus class

Status information for a thermal printer.

Constructors

PrinterStatus({required bool isConnected, bool isPaperOut = false, bool isCoverOpen = false, bool isError = false, String? errorMessage})
const

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
final
isCoverOpen bool
final
isError bool
final
isPaperOut bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited