MethodChannelFlutterThermalPrinterWindows class
An implementation of FlutterThermalPrinterWindowsPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterThermalPrinterWindowsPlatform
- MethodChannelFlutterThermalPrinterWindows
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectToDevice(
BluetoothPrinter printer) → Future< ConnectionResult> -
Connects to the given
printer. Returns ConnectionResult.override -
disconnectFromDevice(
BluetoothPrinter printer) → Future< void> -
Disconnects from the given
printer.override -
getConnectionState(
BluetoothPrinter printer) → Future< ConnectionState> -
Returns the current connection state for
printer.override -
getPairedPrinters(
) → Future< List< BluetoothPrinter> > -
Returns paired Bluetooth printers.
override
-
getPlatformVersion(
) → Future< String?> -
override
-
getPrinterCapabilities(
BluetoothPrinter printer) → Future< PrinterCapabilities> -
Returns capabilities for
printer(paper width, cutting, images, barcodes).override -
getPrinterStatus(
BluetoothPrinter printer) → Future< PrinterStatus> -
Returns current status for
printer(connected, paper, error).override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pairDevice(
BluetoothPrinter printer) → Future< PairingResult> -
Pairs with the given
printer. Returns PairingResult.override -
scanForPrinters(
{Duration? timeout}) → Future< List< BluetoothPrinter> > -
Scans for Bluetooth thermal printers within the given
timeout.override -
sendRawCommands(
BluetoothPrinter printer, Uint8List commands) → Future< void> -
Sends raw ESC/POS
commandstoprinterover Bluetooth.override -
toString(
) → String -
A string representation of this object.
inherited
-
unpairDevice(
BluetoothPrinter printer) → Future< void> -
Unpairs the given
printer.override -
watchConnectionState(
BluetoothPrinter printer) → Stream< ConnectionState> -
Returns a stream of connection state updates for
printer.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited